package com.yaohun.itemlibrary.manage;

import com.yaohun.itemlibrary.data.SortData;
import com.yaohun.itemlibrary.main;
import me.Demon.DemonPlugin.DemonAPI;
import org.bukkit.configuration.ConfigurationSection;
import org.bukkit.configuration.file.FileConfiguration;
import org.bukkit.configuration.file.YamlConfiguration;
import org.bukkit.inventory.ItemStack;

import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.LinkedHashMap;

public class SortManager {

    private LinkedHashMap<String, ItemStack> stackHashMap = new LinkedHashMap<>();
    private LinkedHashMap<String, SortData> sortDataLinkedHashMap = new LinkedHashMap<>();

    public SortManager(){
        File folder = new File(main.plugin.getDataFolder(), "ItemType"); // 获取目录对象
        File[] files = folder.listFiles((dir, name) -> name.endsWith(".yml")); // 列出目录下所有以 .yml 结尾的文件
        if (files != null) { // 确保目录存在且不是空的
            for (File file : files) { // 遍历每个文件
                // 这里可以对每个文件进行操作
                String sortName = file.getName().replace(".yml","");
                FileConfiguration configuration = YamlConfiguration.loadConfiguration(file);
                // 设置默认显示堆叠物品
                String showStack = configuration.getString("showStack", "DIAMOND");
                // 设置物品堆叠
                ConfigurationSection section = configuration.getConfigurationSection("itemStack");
                sortDataLinkedHashMap.put(sortName,new SortData(sortName,showStack,section,file,configuration));
            }
            for (String sortName : sortDataLinkedHashMap.keySet()){
                SortData sortData = sortDataLinkedHashMap.get(sortName);
                for (String itemKey : sortData.getStackLinkedMap().keySet()){
                    stackHashMap.put(itemKey,sortData.getStackLinkedMap().get(itemKey));
                }
            }
            DemonAPI.sendConsoleMessage("§f[§a!§f] §f物品存储 §8> §6"+stackHashMap.size()+" 件");
        }
    }

    /*
    * 创建这个分类文件
    * */
    public void createSortFile(String sortName){
        File file = new File(main.plugin.getDataFolder() + "/ItemType", sortName + ".yml"); // 创建文件对象
        if (!file.exists()) { // 检查文件是否存在
            try {
                file.getParentFile().mkdirs(); // 创建文件夹
                file.createNewFile(); // 创建文件
            } catch (IOException e) {
                e.printStackTrace(); // 捕获并打印IO异常
            }
            // 加载文件配置
            FileConfiguration configuration = YamlConfiguration.loadConfiguration(file);
            // 设置默认显示名称
            configuration.set("showName", "§6§l默认分类名");
            // 设置默认显示堆叠物品
            configuration.set("showStack", "DIAMOND");
            // 设置物品堆叠
            configuration.createSection("itemStack");
            // 保存文件
            saveFile(file, configuration);
        }
    }

    public void SaveSortData(){
        for (String sortName : sortDataLinkedHashMap.keySet()){
            SortData sortData = sortDataLinkedHashMap.get(sortName);
            sortData.SaveData();
        }
    }

    /*
    * 获取分类数据
    * */
    public SortData getSortData(String sortName){
        if (sortDataLinkedHashMap.get(sortName) == null) {
            return null;
        }
        return sortDataLinkedHashMap.get(sortName);
    }

    /*
    * 获取这个分类的文件是否存在
    * */
    public boolean isSortFileExit(String sortName){
        if (sortDataLinkedHashMap.get(sortName) == null) { // 检查文件是否存在
            return false; // 如果文件不存在，返回 false
        }
        return true; // 如果文件存在，返回 true
    }

    public LinkedHashMap<String, SortData> getSortDataLinkedHashMap() {
        return sortDataLinkedHashMap;
    }

    public HashMap<String, ItemStack> getStackHashMap() {
        return stackHashMap;
    }

    public void putStackHashMap(String itemKey,ItemStack stack) {
        this.stackHashMap.put(itemKey,stack);
    }

    public boolean isStackExit(String itemKey){
        if(stackHashMap.get(itemKey) == null){
            return false;
        }
        return true;
    }

    public ItemStack getItemStack(String itemKey){
        if(stackHashMap.get(itemKey) != null){
            return stackHashMap.get(itemKey);
        }
        return DemonAPI.getErrItems();
    }

    /*
    * 保存文件
    * */
    public void saveFile(File file,FileConfiguration fileConfiguration){
        try {
            fileConfiguration.save(file);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
